@@ -1,6 +1,6 @@
 # vat.py - functions for handling United Kingdom VAT numbers
 #
-# Copyright (C) 2012-2015 Arthur de Jong
+# Copyright (C) 2012-2021 Arthur de Jong
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -36,14 +36,14 @@ InvalidChecksum: ...
 """
 
 from stdnum.exceptions import *
-from stdnum.util import clean
+from stdnum.util import clean, isdigits
 
 
 def compact(number):
     """Convert the number to the minimal representation. This strips the
     number of any valid separators and removes surrounding whitespace."""
     number = clean(number, ' -.').upper().strip()
-    if number.startswith('GB'):
+    if number.startswith('GB') or number.startswith('XI'):
         number = number[2:]
     return number
 
@@ -60,7 +60,7 @@ def validate(number):
     formatting and check digit."""
     number = compact(number)
     if len(number) == 5:
-        if not number[2:].isdigit():
+        if not isdigits(number[2:]):
             raise InvalidFormat()
         if number.startswith('GD') and int(number[2:]) < 500:
             # government department
@@ -71,7 +71,7 @@ def validate(number):
         else:
             raise InvalidComponent()
     elif len(number) == 11 and number[0:6] in ('GD8888', 'HA8888'):
-        if not number[6:].isdigit():
+        if not isdigits(number[6:]):
             raise InvalidFormat()
         if number.startswith('GD') and int(number[6:9]) < 500:
             # government department
@@ -84,7 +84,7 @@ def validate(number):
         if int(number[6:9]) % 97 != int(number[9:11]):
             raise InvalidChecksum()
     elif len(number) in (9, 12):
-        if not number.isdigit():
+        if not isdigits(number):
             raise InvalidFormat()
         # standard number: nnn nnnn nn
         # branch trader: nnn nnnn nn nnn (ignore the last thee digits)
