@@ -41,7 +41,7 @@ mas_url = 'http://standards-oui.ieee.org/oui36/oui36.csv'
 def download_csv(url):
     """Download the list from the site and provide assignment and
     organisation names."""
-    response = requests.get(url)
+    response = requests.get(url, timeout=30)
     response.raise_for_status()
     for row in csv.DictReader(line.decode('utf-8') for line in response.iter_lines()):
         o = row['Organization Name'].strip().replace('"', '%')
